# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class ResourcePermissionPolicy(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ResourcePermissionPolicy - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'domain': 'str',
            'entity_name': 'str',
            'policy_name': 'str',
            'policy_description': 'str',
            'action_set_key': 'str',
            'allow_conditions': 'bool',
            'resource_condition_node': 'ResourceConditionNode',
            'named_resources': 'list[str]',
            'resource_condition': 'str',
            'action_set': 'list[str]'
        }

        self.attribute_map = {
            'id': 'id',
            'domain': 'domain',
            'entity_name': 'entityName',
            'policy_name': 'policyName',
            'policy_description': 'policyDescription',
            'action_set_key': 'actionSetKey',
            'allow_conditions': 'allowConditions',
            'resource_condition_node': 'resourceConditionNode',
            'named_resources': 'namedResources',
            'resource_condition': 'resourceCondition',
            'action_set': 'actionSet'
        }

        self._id = None
        self._domain = None
        self._entity_name = None
        self._policy_name = None
        self._policy_description = None
        self._action_set_key = None
        self._allow_conditions = False
        self._resource_condition_node = None
        self._named_resources = None
        self._resource_condition = None
        self._action_set = None

    @property
    def id(self):
        """
        Gets the id of this ResourcePermissionPolicy.


        :return: The id of this ResourcePermissionPolicy.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ResourcePermissionPolicy.


        :param id: The id of this ResourcePermissionPolicy.
        :type: str
        """
        
        self._id = id

    @property
    def domain(self):
        """
        Gets the domain of this ResourcePermissionPolicy.


        :return: The domain of this ResourcePermissionPolicy.
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """
        Sets the domain of this ResourcePermissionPolicy.


        :param domain: The domain of this ResourcePermissionPolicy.
        :type: str
        """
        
        self._domain = domain

    @property
    def entity_name(self):
        """
        Gets the entity_name of this ResourcePermissionPolicy.


        :return: The entity_name of this ResourcePermissionPolicy.
        :rtype: str
        """
        return self._entity_name

    @entity_name.setter
    def entity_name(self, entity_name):
        """
        Sets the entity_name of this ResourcePermissionPolicy.


        :param entity_name: The entity_name of this ResourcePermissionPolicy.
        :type: str
        """
        
        self._entity_name = entity_name

    @property
    def policy_name(self):
        """
        Gets the policy_name of this ResourcePermissionPolicy.


        :return: The policy_name of this ResourcePermissionPolicy.
        :rtype: str
        """
        return self._policy_name

    @policy_name.setter
    def policy_name(self, policy_name):
        """
        Sets the policy_name of this ResourcePermissionPolicy.


        :param policy_name: The policy_name of this ResourcePermissionPolicy.
        :type: str
        """
        
        self._policy_name = policy_name

    @property
    def policy_description(self):
        """
        Gets the policy_description of this ResourcePermissionPolicy.


        :return: The policy_description of this ResourcePermissionPolicy.
        :rtype: str
        """
        return self._policy_description

    @policy_description.setter
    def policy_description(self, policy_description):
        """
        Sets the policy_description of this ResourcePermissionPolicy.


        :param policy_description: The policy_description of this ResourcePermissionPolicy.
        :type: str
        """
        
        self._policy_description = policy_description

    @property
    def action_set_key(self):
        """
        Gets the action_set_key of this ResourcePermissionPolicy.


        :return: The action_set_key of this ResourcePermissionPolicy.
        :rtype: str
        """
        return self._action_set_key

    @action_set_key.setter
    def action_set_key(self, action_set_key):
        """
        Sets the action_set_key of this ResourcePermissionPolicy.


        :param action_set_key: The action_set_key of this ResourcePermissionPolicy.
        :type: str
        """
        
        self._action_set_key = action_set_key

    @property
    def allow_conditions(self):
        """
        Gets the allow_conditions of this ResourcePermissionPolicy.


        :return: The allow_conditions of this ResourcePermissionPolicy.
        :rtype: bool
        """
        return self._allow_conditions

    @allow_conditions.setter
    def allow_conditions(self, allow_conditions):
        """
        Sets the allow_conditions of this ResourcePermissionPolicy.


        :param allow_conditions: The allow_conditions of this ResourcePermissionPolicy.
        :type: bool
        """
        
        self._allow_conditions = allow_conditions

    @property
    def resource_condition_node(self):
        """
        Gets the resource_condition_node of this ResourcePermissionPolicy.


        :return: The resource_condition_node of this ResourcePermissionPolicy.
        :rtype: ResourceConditionNode
        """
        return self._resource_condition_node

    @resource_condition_node.setter
    def resource_condition_node(self, resource_condition_node):
        """
        Sets the resource_condition_node of this ResourcePermissionPolicy.


        :param resource_condition_node: The resource_condition_node of this ResourcePermissionPolicy.
        :type: ResourceConditionNode
        """
        
        self._resource_condition_node = resource_condition_node

    @property
    def named_resources(self):
        """
        Gets the named_resources of this ResourcePermissionPolicy.


        :return: The named_resources of this ResourcePermissionPolicy.
        :rtype: list[str]
        """
        return self._named_resources

    @named_resources.setter
    def named_resources(self, named_resources):
        """
        Sets the named_resources of this ResourcePermissionPolicy.


        :param named_resources: The named_resources of this ResourcePermissionPolicy.
        :type: list[str]
        """
        
        self._named_resources = named_resources

    @property
    def resource_condition(self):
        """
        Gets the resource_condition of this ResourcePermissionPolicy.


        :return: The resource_condition of this ResourcePermissionPolicy.
        :rtype: str
        """
        return self._resource_condition

    @resource_condition.setter
    def resource_condition(self, resource_condition):
        """
        Sets the resource_condition of this ResourcePermissionPolicy.


        :param resource_condition: The resource_condition of this ResourcePermissionPolicy.
        :type: str
        """
        
        self._resource_condition = resource_condition

    @property
    def action_set(self):
        """
        Gets the action_set of this ResourcePermissionPolicy.


        :return: The action_set of this ResourcePermissionPolicy.
        :rtype: list[str]
        """
        return self._action_set

    @action_set.setter
    def action_set(self, action_set):
        """
        Sets the action_set of this ResourcePermissionPolicy.


        :param action_set: The action_set of this ResourcePermissionPolicy.
        :type: list[str]
        """
        
        self._action_set = action_set

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class OrgMediaUtilization(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        OrgMediaUtilization - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'maximum_capacity': 'int',
            'interruptable_media_types': 'list[str]',
            'include_non_acd': 'bool'
        }

        self.attribute_map = {
            'maximum_capacity': 'maximumCapacity',
            'interruptable_media_types': 'interruptableMediaTypes',
            'include_non_acd': 'includeNonAcd'
        }

        self._maximum_capacity = None
        self._interruptable_media_types = None
        self._include_non_acd = False

    @property
    def maximum_capacity(self):
        """
        Gets the maximum_capacity of this OrgMediaUtilization.
        Defines the maximum number of conversations of this type that an agent can handle at one time.

        :return: The maximum_capacity of this OrgMediaUtilization.
        :rtype: int
        """
        return self._maximum_capacity

    @maximum_capacity.setter
    def maximum_capacity(self, maximum_capacity):
        """
        Sets the maximum_capacity of this OrgMediaUtilization.
        Defines the maximum number of conversations of this type that an agent can handle at one time.

        :param maximum_capacity: The maximum_capacity of this OrgMediaUtilization.
        :type: int
        """
        
        self._maximum_capacity = maximum_capacity

    @property
    def interruptable_media_types(self):
        """
        Gets the interruptable_media_types of this OrgMediaUtilization.
        Defines the list of other media types that can interrupt a conversation of this media type.  Values can be: call, chat, email, or socialExpression

        :return: The interruptable_media_types of this OrgMediaUtilization.
        :rtype: list[str]
        """
        return self._interruptable_media_types

    @interruptable_media_types.setter
    def interruptable_media_types(self, interruptable_media_types):
        """
        Sets the interruptable_media_types of this OrgMediaUtilization.
        Defines the list of other media types that can interrupt a conversation of this media type.  Values can be: call, chat, email, or socialExpression

        :param interruptable_media_types: The interruptable_media_types of this OrgMediaUtilization.
        :type: list[str]
        """
        
        self._interruptable_media_types = interruptable_media_types

    @property
    def include_non_acd(self):
        """
        Gets the include_non_acd of this OrgMediaUtilization.
        If true, then track non-ACD conversations against utilization

        :return: The include_non_acd of this OrgMediaUtilization.
        :rtype: bool
        """
        return self._include_non_acd

    @include_non_acd.setter
    def include_non_acd(self, include_non_acd):
        """
        Sets the include_non_acd of this OrgMediaUtilization.
        If true, then track non-ACD conversations against utilization

        :param include_non_acd: The include_non_acd of this OrgMediaUtilization.
        :type: bool
        """
        
        self._include_non_acd = include_non_acd

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

   ref: https://github.com/swagger-api/swagger-codegen
"""

from __future__ import absolute_import

import os
import sys
import unittest

import swagger_client
from swagger_client.rest import ApiException
from swagger_client.apis.outbound_api import OutboundApi


class TestOutboundApi(unittest.TestCase):
    """ OutboundApi unit test stubs """

    def setUp(self):
        self.api = swagger_client.apis.outbound_api.OutboundApi()

    def tearDown(self):
        pass

    def test_delete_callabletimesets_callabletimeset_id(self):
        """
        Test case for delete_callabletimesets_callabletimeset_id

        Delete callable time set
        """
        pass

    def test_delete_callanalysisresponsesets_callanalysisset_id(self):
        """
        Test case for delete_callanalysisresponsesets_callanalysisset_id

        Delete a dialer call analysis response set.
        """
        pass

    def test_delete_campaigns_campaign_id(self):
        """
        Test case for delete_campaigns_campaign_id

        Delete a campaign.
        """
        pass

    def test_delete_campaigns_campaign_id_progress(self):
        """
        Test case for delete_campaigns_campaign_id_progress

        Reset campaign progress and recycle the campaign
        """
        pass

    def test_delete_contactlists_contactlist_id(self):
        """
        Test case for delete_contactlists_contactlist_id

        Delete a contact list.
        """
        pass

    def test_delete_contactlists_contactlist_id_contacts_contact_id(self):
        """
        Test case for delete_contactlists_contactlist_id_contacts_contact_id

        Delete a contact.
        """
        pass

    def test_delete_dnclists_dnclist_id(self):
        """
        Test case for delete_dnclists_dnclist_id

        Delete dialer DNC list
        """
        pass

    def test_delete_rulesets_ruleset_id(self):
        """
        Test case for delete_rulesets_ruleset_id

        Delete a Rule set.
        """
        pass

    def test_delete_schedules_campaigns_campaign_id(self):
        """
        Test case for delete_schedules_campaigns_campaign_id

        Delete a dialer campaign schedule.
        """
        pass

    def test_delete_schedules_sequences_sequence_id(self):
        """
        Test case for delete_schedules_sequences_sequence_id

        Delete a dialer sequence schedule.
        """
        pass

    def test_delete_sequences_sequence_id(self):
        """
        Test case for delete_sequences_sequence_id

        Delete a dialer campaign sequence.
        """
        pass

    def test_get_callabletimesets(self):
        """
        Test case for get_callabletimesets

        Query callable time set list
        """
        pass

    def test_get_callabletimesets_callabletimeset_id(self):
        """
        Test case for get_callabletimesets_callabletimeset_id

        Get callable time set
        """
        pass

    def test_get_callanalysisresponsesets(self):
        """
        Test case for get_callanalysisresponsesets

        Query a list of dialer call analysis response sets.
        """
        pass

    def test_get_callanalysisresponsesets_callanalysisset_id(self):
        """
        Test case for get_callanalysisresponsesets_callanalysisset_id

        Get a dialer call analysis response set.
        """
        pass

    def test_get_campaigns(self):
        """
        Test case for get_campaigns

        Query a list of dialer campaigns.
        """
        pass

    def test_get_campaigns_campaign_id(self):
        """
        Test case for get_campaigns_campaign_id

        Get dialer campaign.
        """
        pass

    def test_get_campaigns_campaign_id_diagnostics(self):
        """
        Test case for get_campaigns_campaign_id_diagnostics

        Get campaign diagnostics
        """
        pass

    def test_get_campaigns_campaign_id_progress(self):
        """
        Test case for get_campaigns_campaign_id_progress

        Get campaign progress
        """
        pass

    def test_get_campaigns_campaign_id_stats(self):
        """
        Test case for get_campaigns_campaign_id_stats

        Get statistics about a Dialer Campaign
        """
        pass

    def test_get_contactlists(self):
        """
        Test case for get_contactlists

        Query a list of contact lists.
        """
        pass

    def test_get_contactlists_contactlist_id(self):
        """
        Test case for get_contactlists_contactlist_id

        Get a dialer contact list.
        """
        pass

    def test_get_contactlists_contactlist_id_contacts_contact_id(self):
        """
        Test case for get_contactlists_contactlist_id_contacts_contact_id

        Get a contact.
        """
        pass

    def test_get_contactlists_contactlist_id_export(self):
        """
        Test case for get_contactlists_contactlist_id_export

        Get the URI of a contact list export.
        """
        pass

    def test_get_contactlists_contactlist_id_importstatus(self):
        """
        Test case for get_contactlists_contactlist_id_importstatus

        Get dialer contactList import status.
        """
        pass

    def test_get_dnclists(self):
        """
        Test case for get_dnclists

        Query dialer DNC lists
        """
        pass

    def test_get_dnclists_dnclist_id(self):
        """
        Test case for get_dnclists_dnclist_id

        Get dialer DNC list
        """
        pass

    def test_get_dnclists_dnclist_id_export(self):
        """
        Test case for get_dnclists_dnclist_id_export

        Get the URI of a DNC list export.
        """
        pass

    def test_get_dnclists_dnclist_id_importstatus(self):
        """
        Test case for get_dnclists_dnclist_id_importstatus

        Get dialer dncList import status.
        """
        pass

    def test_get_rulesets(self):
        """
        Test case for get_rulesets

        Query a list of Rule Sets.
        """
        pass

    def test_get_rulesets_ruleset_id(self):
        """
        Test case for get_rulesets_ruleset_id

        Get a Rule Set by ID.
        """
        pass

    def test_get_schedules_campaigns(self):
        """
        Test case for get_schedules_campaigns

        Query for a list of dialer campaign schedules.
        """
        pass

    def test_get_schedules_campaigns_campaign_id(self):
        """
        Test case for get_schedules_campaigns_campaign_id

        Get a dialer campaign schedule.
        """
        pass

    def test_get_schedules_sequences(self):
        """
        Test case for get_schedules_sequences

        Query for a list of dialer sequence schedules.
        """
        pass

    def test_get_schedules_sequences_sequence_id(self):
        """
        Test case for get_schedules_sequences_sequence_id

        Get a dialer sequence schedule.
        """
        pass

    def test_get_sequences(self):
        """
        Test case for get_sequences

        Query a list of dialer campaign sequences.
        """
        pass

    def test_get_sequences_sequence_id(self):
        """
        Test case for get_sequences_sequence_id

        Get a dialer campaign sequence.
        """
        pass

    def test_get_wrapupcodemappings(self):
        """
        Test case for get_wrapupcodemappings

        Get the Dialer wrap up code mapping.
        """
        pass

    def test_post_audits(self):
        """
        Test case for post_audits

        Retrieves audits for dialer.
        """
        pass

    def test_post_callabletimesets(self):
        """
        Test case for post_callabletimesets

        Create callable time set
        """
        pass

    def test_post_callanalysisresponsesets(self):
        """
        Test case for post_callanalysisresponsesets

        Create a dialer call analysis response set.
        """
        pass

    def test_post_campaigns(self):
        """
        Test case for post_campaigns

        Create a campaign.
        """
        pass

    def test_post_campaigns_campaign_id_callback_schedule(self):
        """
        Test case for post_campaigns_campaign_id_callback_schedule

        Schedule a Callback for a Dialer Campaign
        """
        pass

    def test_post_campaigns_progress(self):
        """
        Test case for post_campaigns_progress

        Get progress for a list of campaigns
        """
        pass

    def test_post_contactlists(self):
        """
        Test case for post_contactlists

        Create a contact List.
        """
        pass

    def test_post_contactlists_contactlist_id_contacts(self):
        """
        Test case for post_contactlists_contactlist_id_contacts

        Add contacts to a contact list.
        """
        pass

    def test_post_contactlists_contactlist_id_export(self):
        """
        Test case for post_contactlists_contactlist_id_export

        Initiate the export of a contact list.
        """
        pass

    def test_post_conversations_conversation_id_dnc(self):
        """
        Test case for post_conversations_conversation_id_dnc

        Add phone numbers to a Dialer DNC list.
        """
        pass

    def test_post_dnclists(self):
        """
        Test case for post_dnclists

        Create dialer DNC list
        """
        pass

    def test_post_dnclists_dnclist_id_export(self):
        """
        Test case for post_dnclists_dnclist_id_export

        Initiate the export of a dnc list.
        """
        pass

    def test_post_dnclists_dnclist_id_phonenumbers(self):
        """
        Test case for post_dnclists_dnclist_id_phonenumbers

        Add phone numbers to a Dialer DNC list.
        """
        pass

    def test_post_rulesets(self):
        """
        Test case for post_rulesets

        Create a Dialer Call Analysis Response Set.
        """
        pass

    def test_post_sequences(self):
        """
        Test case for post_sequences

        Create a new campaign sequence.
        """
        pass

    def test_put_callabletimesets_callabletimeset_id(self):
        """
        Test case for put_callabletimesets_callabletimeset_id

        Update callable time set
        """
        pass

    def test_put_callanalysisresponsesets_callanalysisset_id(self):
        """
        Test case for put_callanalysisresponsesets_callanalysisset_id

        Update a dialer call analysis response set.
        """
        pass

    def test_put_campaigns_campaign_id(self):
        """
        Test case for put_campaigns_campaign_id

        Update a campaign.
        """
        pass

    def test_put_campaigns_campaign_id_agents_user_id(self):
        """
        Test case for put_campaigns_campaign_id_agents_user_id

        Send notification that an agent's state changed 
        """
        pass

    def test_put_contactlists_contactlist_id(self):
        """
        Test case for put_contactlists_contactlist_id

        Update a contact list.
        """
        pass

    def test_put_contactlists_contactlist_id_contacts_contact_id(self):
        """
        Test case for put_contactlists_contactlist_id_contacts_contact_id

        Update a contact.
        """
        pass

    def test_put_dnclists_dnclist_id(self):
        """
        Test case for put_dnclists_dnclist_id

        Update dialer DNC list
        """
        pass

    def test_put_rulesets_ruleset_id(self):
        """
        Test case for put_rulesets_ruleset_id

        Update a RuleSet.
        """
        pass

    def test_put_schedules_campaigns_campaign_id(self):
        """
        Test case for put_schedules_campaigns_campaign_id

        Update a new campaign schedule.
        """
        pass

    def test_put_schedules_sequences_sequence_id(self):
        """
        Test case for put_schedules_sequences_sequence_id

        Update a new sequence schedule.
        """
        pass

    def test_put_sequences_sequence_id(self):
        """
        Test case for put_sequences_sequence_id

        Update a new campaign sequence.
        """
        pass

    def test_put_wrapupcodemappings(self):
        """
        Test case for put_wrapupcodemappings

        Update the Dialer wrap up code mapping.
        """
        pass


if __name__ == '__main__':
    unittest.main()


# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class DialerAction(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DialerAction - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'type': 'str',
            'action_type_name': 'str',
            'update_option': 'str',
            'properties': 'dict(str, str)'
        }

        self.attribute_map = {
            'type': 'type',
            'action_type_name': 'actionTypeName',
            'update_option': 'updateOption',
            'properties': 'properties'
        }

        self._type = None
        self._action_type_name = None
        self._update_option = None
        self._properties = None

    @property
    def type(self):
        """
        Gets the type of this DialerAction.
        Type of the action

        :return: The type of this DialerAction.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this DialerAction.
        Type of the action

        :param type: The type of this DialerAction.
        :type: str
        """
        allowed_values = ["Action", "modifyContactAttribute"]
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type`, must be one of {0}"
                .format(allowed_values)
            )

        self._type = type

    @property
    def action_type_name(self):
        """
        Gets the action_type_name of this DialerAction.
        Identifier of the action

        :return: The action_type_name of this DialerAction.
        :rtype: str
        """
        return self._action_type_name

    @action_type_name.setter
    def action_type_name(self, action_type_name):
        """
        Sets the action_type_name of this DialerAction.
        Identifier of the action

        :param action_type_name: The action_type_name of this DialerAction.
        :type: str
        """
        allowed_values = ["DO_NOT_DIAL", "MODIFY_CONTACT_ATTRIBUTE", "SWITCH_TO_PREVIEW", "APPEND_NUMBER_TO_DNC_LIST", "SCHEDULE_CALLBACK"]
        if action_type_name not in allowed_values:
            raise ValueError(
                "Invalid value for `action_type_name`, must be one of {0}"
                .format(allowed_values)
            )

        self._action_type_name = action_type_name

    @property
    def update_option(self):
        """
        Gets the update_option of this DialerAction.
        Indicator of the type of update action (applicable only to certain types of actions)

        :return: The update_option of this DialerAction.
        :rtype: str
        """
        return self._update_option

    @update_option.setter
    def update_option(self, update_option):
        """
        Sets the update_option of this DialerAction.
        Indicator of the type of update action (applicable only to certain types of actions)

        :param update_option: The update_option of this DialerAction.
        :type: str
        """
        allowed_values = ["SET", "INCREMENT", "DECREMENT", "CURRENT_TIME"]
        if update_option not in allowed_values:
            raise ValueError(
                "Invalid value for `update_option`, must be one of {0}"
                .format(allowed_values)
            )

        self._update_option = update_option

    @property
    def properties(self):
        """
        Gets the properties of this DialerAction.
        Map of key-value pairs pertinent to the action (different actions require different properties)

        :return: The properties of this DialerAction.
        :rtype: dict(str, str)
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """
        Sets the properties of this DialerAction.
        Map of key-value pairs pertinent to the action (different actions require different properties)

        :param properties: The properties of this DialerAction.
        :type: dict(str, str)
        """
        
        self._properties = properties

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class Organization(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Organization - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'third_party_org_id': 'str',
            'third_party_org_name': 'str',
            'third_party_uri': 'str',
            'domain': 'str',
            'version': 'int',
            'state': 'str',
            'default_site_id': 'str',
            'deletable': 'bool',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'third_party_org_id': 'thirdPartyOrgId',
            'third_party_org_name': 'thirdPartyOrgName',
            'third_party_uri': 'thirdPartyURI',
            'domain': 'domain',
            'version': 'version',
            'state': 'state',
            'default_site_id': 'defaultSiteId',
            'deletable': 'deletable',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._third_party_org_id = None
        self._third_party_org_name = None
        self._third_party_uri = None
        self._domain = None
        self._version = None
        self._state = None
        self._default_site_id = None
        self._deletable = False
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this Organization.
        The globally unique identifier for the object.

        :return: The id of this Organization.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Organization.
        The globally unique identifier for the object.

        :param id: The id of this Organization.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Organization.


        :return: The name of this Organization.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Organization.


        :param name: The name of this Organization.
        :type: str
        """
        
        self._name = name

    @property
    def third_party_org_id(self):
        """
        Gets the third_party_org_id of this Organization.


        :return: The third_party_org_id of this Organization.
        :rtype: str
        """
        return self._third_party_org_id

    @third_party_org_id.setter
    def third_party_org_id(self, third_party_org_id):
        """
        Sets the third_party_org_id of this Organization.


        :param third_party_org_id: The third_party_org_id of this Organization.
        :type: str
        """
        
        self._third_party_org_id = third_party_org_id

    @property
    def third_party_org_name(self):
        """
        Gets the third_party_org_name of this Organization.


        :return: The third_party_org_name of this Organization.
        :rtype: str
        """
        return self._third_party_org_name

    @third_party_org_name.setter
    def third_party_org_name(self, third_party_org_name):
        """
        Sets the third_party_org_name of this Organization.


        :param third_party_org_name: The third_party_org_name of this Organization.
        :type: str
        """
        
        self._third_party_org_name = third_party_org_name

    @property
    def third_party_uri(self):
        """
        Gets the third_party_uri of this Organization.


        :return: The third_party_uri of this Organization.
        :rtype: str
        """
        return self._third_party_uri

    @third_party_uri.setter
    def third_party_uri(self, third_party_uri):
        """
        Sets the third_party_uri of this Organization.


        :param third_party_uri: The third_party_uri of this Organization.
        :type: str
        """
        
        self._third_party_uri = third_party_uri

    @property
    def domain(self):
        """
        Gets the domain of this Organization.


        :return: The domain of this Organization.
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """
        Sets the domain of this Organization.


        :param domain: The domain of this Organization.
        :type: str
        """
        
        self._domain = domain

    @property
    def version(self):
        """
        Gets the version of this Organization.
        The current version of the organization.

        :return: The version of this Organization.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this Organization.
        The current version of the organization.

        :param version: The version of this Organization.
        :type: int
        """
        
        self._version = version

    @property
    def state(self):
        """
        Gets the state of this Organization.


        :return: The state of this Organization.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this Organization.


        :param state: The state of this Organization.
        :type: str
        """
        allowed_values = ["active", "inactive", "deleted"]
        if state not in allowed_values:
            raise ValueError(
                "Invalid value for `state`, must be one of {0}"
                .format(allowed_values)
            )

        self._state = state

    @property
    def default_site_id(self):
        """
        Gets the default_site_id of this Organization.


        :return: The default_site_id of this Organization.
        :rtype: str
        """
        return self._default_site_id

    @default_site_id.setter
    def default_site_id(self, default_site_id):
        """
        Sets the default_site_id of this Organization.


        :param default_site_id: The default_site_id of this Organization.
        :type: str
        """
        
        self._default_site_id = default_site_id

    @property
    def deletable(self):
        """
        Gets the deletable of this Organization.


        :return: The deletable of this Organization.
        :rtype: bool
        """
        return self._deletable

    @deletable.setter
    def deletable(self, deletable):
        """
        Sets the deletable of this Organization.


        :param deletable: The deletable of this Organization.
        :type: bool
        """
        
        self._deletable = deletable

    @property
    def self_uri(self):
        """
        Gets the self_uri of this Organization.
        The URI for this object

        :return: The self_uri of this Organization.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this Organization.
        The URI for this object

        :param self_uri: The self_uri of this Organization.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class Policy(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Policy - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'modified_date': 'datetime',
            'created_date': 'datetime',
            'order': 'int',
            'description': 'str',
            'enabled': 'bool',
            'media_policies': 'MediaPolicies',
            'conditions': 'PolicyConditions',
            'actions': 'PolicyActions',
            'policy_errors': 'PolicyErrors',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'modified_date': 'modifiedDate',
            'created_date': 'createdDate',
            'order': 'order',
            'description': 'description',
            'enabled': 'enabled',
            'media_policies': 'mediaPolicies',
            'conditions': 'conditions',
            'actions': 'actions',
            'policy_errors': 'policyErrors',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._modified_date = None
        self._created_date = None
        self._order = None
        self._description = None
        self._enabled = False
        self._media_policies = None
        self._conditions = None
        self._actions = None
        self._policy_errors = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this Policy.
        The globally unique identifier for the object.

        :return: The id of this Policy.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Policy.
        The globally unique identifier for the object.

        :param id: The id of this Policy.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Policy.


        :return: The name of this Policy.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Policy.


        :param name: The name of this Policy.
        :type: str
        """
        
        self._name = name

    @property
    def modified_date(self):
        """
        Gets the modified_date of this Policy.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The modified_date of this Policy.
        :rtype: datetime
        """
        return self._modified_date

    @modified_date.setter
    def modified_date(self, modified_date):
        """
        Sets the modified_date of this Policy.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param modified_date: The modified_date of this Policy.
        :type: datetime
        """
        
        self._modified_date = modified_date

    @property
    def created_date(self):
        """
        Gets the created_date of this Policy.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The created_date of this Policy.
        :rtype: datetime
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """
        Sets the created_date of this Policy.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param created_date: The created_date of this Policy.
        :type: datetime
        """
        
        self._created_date = created_date

    @property
    def order(self):
        """
        Gets the order of this Policy.


        :return: The order of this Policy.
        :rtype: int
        """
        return self._order

    @order.setter
    def order(self, order):
        """
        Sets the order of this Policy.


        :param order: The order of this Policy.
        :type: int
        """
        
        self._order = order

    @property
    def description(self):
        """
        Gets the description of this Policy.


        :return: The description of this Policy.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Policy.


        :param description: The description of this Policy.
        :type: str
        """
        
        self._description = description

    @property
    def enabled(self):
        """
        Gets the enabled of this Policy.


        :return: The enabled of this Policy.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this Policy.


        :param enabled: The enabled of this Policy.
        :type: bool
        """
        
        self._enabled = enabled

    @property
    def media_policies(self):
        """
        Gets the media_policies of this Policy.
        Conditions and actions per media type

        :return: The media_policies of this Policy.
        :rtype: MediaPolicies
        """
        return self._media_policies

    @media_policies.setter
    def media_policies(self, media_policies):
        """
        Sets the media_policies of this Policy.
        Conditions and actions per media type

        :param media_policies: The media_policies of this Policy.
        :type: MediaPolicies
        """
        
        self._media_policies = media_policies

    @property
    def conditions(self):
        """
        Gets the conditions of this Policy.
        Conditions

        :return: The conditions of this Policy.
        :rtype: PolicyConditions
        """
        return self._conditions

    @conditions.setter
    def conditions(self, conditions):
        """
        Sets the conditions of this Policy.
        Conditions

        :param conditions: The conditions of this Policy.
        :type: PolicyConditions
        """
        
        self._conditions = conditions

    @property
    def actions(self):
        """
        Gets the actions of this Policy.
        Actions

        :return: The actions of this Policy.
        :rtype: PolicyActions
        """
        return self._actions

    @actions.setter
    def actions(self, actions):
        """
        Sets the actions of this Policy.
        Actions

        :param actions: The actions of this Policy.
        :type: PolicyActions
        """
        
        self._actions = actions

    @property
    def policy_errors(self):
        """
        Gets the policy_errors of this Policy.


        :return: The policy_errors of this Policy.
        :rtype: PolicyErrors
        """
        return self._policy_errors

    @policy_errors.setter
    def policy_errors(self, policy_errors):
        """
        Sets the policy_errors of this Policy.


        :param policy_errors: The policy_errors of this Policy.
        :type: PolicyErrors
        """
        
        self._policy_errors = policy_errors

    @property
    def self_uri(self):
        """
        Gets the self_uri of this Policy.
        The URI for this object

        :return: The self_uri of this Policy.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this Policy.
        The URI for this object

        :param self_uri: The self_uri of this Policy.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class Extension(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Extension - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'version': 'int',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'modified_by': 'str',
            'created_by': 'str',
            'state': 'str',
            'modified_by_app': 'str',
            'created_by_app': 'str',
            'number': 'str',
            'owner': 'UriReference',
            'extension_pool': 'UriReference',
            'owner_type': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'version': 'version',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'modified_by': 'modifiedBy',
            'created_by': 'createdBy',
            'state': 'state',
            'modified_by_app': 'modifiedByApp',
            'created_by_app': 'createdByApp',
            'number': 'number',
            'owner': 'owner',
            'extension_pool': 'extensionPool',
            'owner_type': 'ownerType',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._description = None
        self._version = None
        self._date_created = None
        self._date_modified = None
        self._modified_by = None
        self._created_by = None
        self._state = None
        self._modified_by_app = None
        self._created_by_app = None
        self._number = None
        self._owner = None
        self._extension_pool = None
        self._owner_type = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this Extension.
        The globally unique identifier for the object.

        :return: The id of this Extension.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Extension.
        The globally unique identifier for the object.

        :param id: The id of this Extension.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Extension.


        :return: The name of this Extension.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Extension.


        :param name: The name of this Extension.
        :type: str
        """
        
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this Extension.


        :return: The description of this Extension.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Extension.


        :param description: The description of this Extension.
        :type: str
        """
        
        self._description = description

    @property
    def version(self):
        """
        Gets the version of this Extension.


        :return: The version of this Extension.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this Extension.


        :param version: The version of this Extension.
        :type: int
        """
        
        self._version = version

    @property
    def date_created(self):
        """
        Gets the date_created of this Extension.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_created of this Extension.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this Extension.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_created: The date_created of this Extension.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this Extension.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_modified of this Extension.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this Extension.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_modified: The date_modified of this Extension.
        :type: datetime
        """
        
        self._date_modified = date_modified

    @property
    def modified_by(self):
        """
        Gets the modified_by of this Extension.


        :return: The modified_by of this Extension.
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """
        Sets the modified_by of this Extension.


        :param modified_by: The modified_by of this Extension.
        :type: str
        """
        
        self._modified_by = modified_by

    @property
    def created_by(self):
        """
        Gets the created_by of this Extension.


        :return: The created_by of this Extension.
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this Extension.


        :param created_by: The created_by of this Extension.
        :type: str
        """
        
        self._created_by = created_by

    @property
    def state(self):
        """
        Gets the state of this Extension.


        :return: The state of this Extension.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this Extension.


        :param state: The state of this Extension.
        :type: str
        """
        allowed_values = ["active", "inactive", "deleted"]
        if state not in allowed_values:
            raise ValueError(
                "Invalid value for `state`, must be one of {0}"
                .format(allowed_values)
            )

        self._state = state

    @property
    def modified_by_app(self):
        """
        Gets the modified_by_app of this Extension.


        :return: The modified_by_app of this Extension.
        :rtype: str
        """
        return self._modified_by_app

    @modified_by_app.setter
    def modified_by_app(self, modified_by_app):
        """
        Sets the modified_by_app of this Extension.


        :param modified_by_app: The modified_by_app of this Extension.
        :type: str
        """
        
        self._modified_by_app = modified_by_app

    @property
    def created_by_app(self):
        """
        Gets the created_by_app of this Extension.


        :return: The created_by_app of this Extension.
        :rtype: str
        """
        return self._created_by_app

    @created_by_app.setter
    def created_by_app(self, created_by_app):
        """
        Sets the created_by_app of this Extension.


        :param created_by_app: The created_by_app of this Extension.
        :type: str
        """
        
        self._created_by_app = created_by_app

    @property
    def number(self):
        """
        Gets the number of this Extension.


        :return: The number of this Extension.
        :rtype: str
        """
        return self._number

    @number.setter
    def number(self, number):
        """
        Sets the number of this Extension.


        :param number: The number of this Extension.
        :type: str
        """
        
        self._number = number

    @property
    def owner(self):
        """
        Gets the owner of this Extension.
        A Uri reference to the owner of this extension, which is either a User or an IVR

        :return: The owner of this Extension.
        :rtype: UriReference
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """
        Sets the owner of this Extension.
        A Uri reference to the owner of this extension, which is either a User or an IVR

        :param owner: The owner of this Extension.
        :type: UriReference
        """
        
        self._owner = owner

    @property
    def extension_pool(self):
        """
        Gets the extension_pool of this Extension.


        :return: The extension_pool of this Extension.
        :rtype: UriReference
        """
        return self._extension_pool

    @extension_pool.setter
    def extension_pool(self, extension_pool):
        """
        Sets the extension_pool of this Extension.


        :param extension_pool: The extension_pool of this Extension.
        :type: UriReference
        """
        
        self._extension_pool = extension_pool

    @property
    def owner_type(self):
        """
        Gets the owner_type of this Extension.


        :return: The owner_type of this Extension.
        :rtype: str
        """
        return self._owner_type

    @owner_type.setter
    def owner_type(self, owner_type):
        """
        Sets the owner_type of this Extension.


        :param owner_type: The owner_type of this Extension.
        :type: str
        """
        allowed_values = ["USER", "PHONE", "IVR_CONFIG", "GROUP"]
        if owner_type not in allowed_values:
            raise ValueError(
                "Invalid value for `owner_type`, must be one of {0}"
                .format(allowed_values)
            )

        self._owner_type = owner_type

    @property
    def self_uri(self):
        """
        Gets the self_uri of this Extension.
        The URI for this object

        :return: The self_uri of this Extension.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this Extension.
        The URI for this object

        :param self_uri: The self_uri of this Extension.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




from __future__ import absolute_import

# import models into model package
from .adfs import ADFS
from .actions import Actions
from .acw_settings import AcwSettings
from .agent import Agent
from .agent_activity import AgentActivity
from .agent_activity_entity_listing import AgentActivityEntityListing
from .agent_evaluator_activity import AgentEvaluatorActivity
from .aggregate_data_container import AggregateDataContainer
from .aggregate_metric_data import AggregateMetricData
from .aggregate_query_response import AggregateQueryResponse
from .aggregation_query import AggregationQuery
from .aggregation_range import AggregationRange
from .aggregation_result import AggregationResult
from .aggregation_result_entry import AggregationResultEntry
from .analytics_conversation import AnalyticsConversation
from .analytics_conversation_query_response import AnalyticsConversationQueryResponse
from .analytics_conversation_segment import AnalyticsConversationSegment
from .analytics_evaluation import AnalyticsEvaluation
from .analytics_participant import AnalyticsParticipant
from .analytics_property import AnalyticsProperty
from .analytics_query_aggregation import AnalyticsQueryAggregation
from .analytics_query_clause import AnalyticsQueryClause
from .analytics_query_filter import AnalyticsQueryFilter
from .analytics_query_predicate import AnalyticsQueryPredicate
from .analytics_session import AnalyticsSession
from .annotation import Annotation
from .archive_retention import ArchiveRetention
from .attachment import Attachment
from .attribute import Attribute
from .attribute_entity_listing import AttributeEntityListing
from .attribute_filter_item import AttributeFilterItem
from .attribute_query_request import AttributeQueryRequest
from .audit_change import AuditChange
from .audit_entity import AuditEntity
from .audit_entity_reference import AuditEntityReference
from .audit_facet import AuditFacet
from .audit_filter import AuditFilter
from .audit_message import AuditMessage
from .audit_search_result import AuditSearchResult
from .audit_user import AuditUser
from .available_language_list import AvailableLanguageList
from .available_topic import AvailableTopic
from .available_topic_entity_listing import AvailableTopicEntityListing
from .bullseye import Bullseye
from .calibration import Calibration
from .calibration_assignment import CalibrationAssignment
from .calibration_entity_listing import CalibrationEntityListing
from .call import Call
from .call_command import CallCommand
from .call_conversation import CallConversation
from .call_conversation_entity_listing import CallConversationEntityListing
from .call_forwarding import CallForwarding
from .call_media_participant import CallMediaParticipant
from .call_media_policy import CallMediaPolicy
from .call_media_policy_conditions import CallMediaPolicyConditions
from .call_record import CallRecord
from .callable_contacts_diagnostic import CallableContactsDiagnostic
from .callable_time import CallableTime
from .callable_time_set import CallableTimeSet
from .callable_time_set_entity_listing import CallableTimeSetEntityListing
from .callback import Callback
from .callback_conversation import CallbackConversation
from .callback_conversation_entity_listing import CallbackConversationEntityListing
from .callback_identifier import CallbackIdentifier
from .callback_media_participant import CallbackMediaParticipant
from .campaign import Campaign
from .campaign_diagnostics import CampaignDiagnostics
from .campaign_entity_listing import CampaignEntityListing
from .campaign_progress import CampaignProgress
from .campaign_schedule import CampaignSchedule
from .campaign_sequence import CampaignSequence
from .campaign_sequence_entity_listing import CampaignSequenceEntityListing
from .campaign_stats import CampaignStats
from .campaign_time_slot import CampaignTimeSlot
from .certificate import Certificate
from .certificate_authority_entity_listing import CertificateAuthorityEntityListing
from .certificate_details import CertificateDetails
from .change import Change
from .channel import Channel
from .channel_entity_listing import ChannelEntityListing
from .channel_topic import ChannelTopic
from .channel_topic_entity_listing import ChannelTopicEntityListing
from .chat import Chat
from .chat_conversation import ChatConversation
from .chat_conversation_entity_listing import ChatConversationEntityListing
from .chat_media_participant import ChatMediaParticipant
from .chat_media_policy import ChatMediaPolicy
from .chat_media_policy_conditions import ChatMediaPolicyConditions
from .chat_message import ChatMessage
from .chat_message_user import ChatMessageUser
from .command_status import CommandStatus
from .command_status_entity_listing import CommandStatusEntityListing
from .condition import Condition
from .connect_rate import ConnectRate
from .consult_transfer import ConsultTransfer
from .consult_transfer_response import ConsultTransferResponse
from .consult_transfer_update import ConsultTransferUpdate
from .contact import Contact
from .contact_callback_request import ContactCallbackRequest
from .contact_list import ContactList
from .contact_list_entity_listing import ContactListEntityListing
from .contact_phone_number_column import ContactPhoneNumberColumn
from .contact_sort import ContactSort
from .content_attribute_filter_item import ContentAttributeFilterItem
from .content_facet_filter_item import ContentFacetFilterItem
from .content_filter_item import ContentFilterItem
from .content_query_request import ContentQueryRequest
from .content_sort_item import ContentSortItem
from .conversation import Conversation
from .conversation_chat import ConversationChat
from .conversation_entity_listing import ConversationEntityListing
from .conversation_query import ConversationQuery
from .cover_sheet import CoverSheet
from .create_call_request import CreateCallRequest
from .create_call_response import CreateCallResponse
from .create_callback_command import CreateCallbackCommand
from .create_callback_response import CreateCallbackResponse
from .create_share_request import CreateShareRequest
from .create_share_request_member import CreateShareRequestMember
from .create_share_response import CreateShareResponse
from .create_user import CreateUser
from .customer_interaction_center import CustomerInteractionCenter
from .did import DID
from .did_entity_listing import DIDEntityListing
from .did_pool import DIDPool
from .did_pool_entity_listing import DIDPoolEntityListing
from .default_greeting_list import DefaultGreetingList
from .delete_retention import DeleteRetention
from .destination import Destination
from .detail import Detail
from .dialer_action import DialerAction
from .dialer_audit_request import DialerAuditRequest
from .dialer_contact import DialerContact
from .dialer_contact_entity_listing import DialerContactEntityListing
from .dialer_preview import DialerPreview
from .dialer_rule import DialerRule
from .digit_length import DigitLength
from .disconnect_reason import DisconnectReason
from .dnc_list import DncList
from .dnc_list_entity_listing import DncListEntityListing
from .document import Document
from .document_attribute import DocumentAttribute
from .document_audit import DocumentAudit
from .document_audit_entity_listing import DocumentAuditEntityListing
from .document_entity_listing import DocumentEntityListing
from .document_thumbnail import DocumentThumbnail
from .document_update import DocumentUpdate
from .document_upload import DocumentUpload
from .domain_capabilities import DomainCapabilities
from .domain_certificate_authority import DomainCertificateAuthority
from .domain_edge_software_update_dto import DomainEdgeSoftwareUpdateDto
from .domain_edge_software_version_dto import DomainEdgeSoftwareVersionDto
from .domain_entity import DomainEntity
from .domain_entity_listing import DomainEntityListing
from .domain_entity_listing_evaluation_form import DomainEntityListingEvaluationForm
from .domain_entity_listing_query_result import DomainEntityListingQueryResult
from .domain_logical_interface import DomainLogicalInterface
from .domain_network_address import DomainNetworkAddress
from .domain_network_command_response import DomainNetworkCommandResponse
from .domain_network_route import DomainNetworkRoute
from .domain_org_role_difference import DomainOrgRoleDifference
from .domain_organization_product import DomainOrganizationProduct
from .domain_organization_role import DomainOrganizationRole
from .domain_permission import DomainPermission
from .domain_permission_collection import DomainPermissionCollection
from .domain_permission_policy import DomainPermissionPolicy
from .domain_physical_capabilities import DomainPhysicalCapabilities
from .domain_physical_interface import DomainPhysicalInterface
from .domain_resource_condition_node import DomainResourceConditionNode
from .domain_resource_condition_value import DomainResourceConditionValue
from .domain_role import DomainRole
from .domain_schema_reference import DomainSchemaReference
from .download_response import DownloadResponse
from .duration_condition import DurationCondition
from .edge import Edge
from .edge_auto_update_config import EdgeAutoUpdateConfig
from .edge_entity_listing import EdgeEntityListing
from .edge_group import EdgeGroup
from .edge_group_entity_listing import EdgeGroupEntityListing
from .edge_interface import EdgeInterface
from .edge_line import EdgeLine
from .edge_line_entity_listing import EdgeLineEntityListing
from .edge_logs_job import EdgeLogsJob
from .edge_logs_job_file import EdgeLogsJobFile
from .edge_logs_job_request import EdgeLogsJobRequest
from .edge_logs_job_response import EdgeLogsJobResponse
from .edge_logs_job_upload_request import EdgeLogsJobUploadRequest
from .edge_version_information import EdgeVersionInformation
from .edge_version_report import EdgeVersionReport
from .email import Email
from .email_address import EmailAddress
from .email_attachment import EmailAttachment
from .email_conversation import EmailConversation
from .email_conversation_entity_listing import EmailConversationEntityListing
from .email_media_participant import EmailMediaParticipant
from .email_media_policy import EmailMediaPolicy
from .email_media_policy_conditions import EmailMediaPolicyConditions
from .email_message import EmailMessage
from .email_message_listing import EmailMessageListing
from .email_setup import EmailSetup
from .encryption_key import EncryptionKey
from .encryption_key_entity_listing import EncryptionKeyEntityListing
from .endpoint import Endpoint
from .endpoint_entity_listing import EndpointEntityListing
from .entry import Entry
from .error_body import ErrorBody
from .error_details import ErrorDetails
from .estimated_wait_time_predictions import EstimatedWaitTimePredictions
from .evaluation import Evaluation
from .evaluation_assignment import EvaluationAssignment
from .evaluation_entity_listing import EvaluationEntityListing
from .evaluation_form import EvaluationForm
from .evaluation_form_and_scoring_set import EvaluationFormAndScoringSet
from .evaluation_form_entity_listing import EvaluationFormEntityListing
from .evaluation_scoring_set import EvaluationScoringSet
from .evaluator_activity import EvaluatorActivity
from .evaluator_activity_entity_listing import EvaluatorActivityEntityListing
from .expansion_criterium import ExpansionCriterium
from .export_uri import ExportUri
from .extension import Extension
from .extension_entity_listing import ExtensionEntityListing
from .extension_pool import ExtensionPool
from .extension_pool_entity_listing import ExtensionPoolEntityListing
from .facet_entry import FacetEntry
from .facet_info import FacetInfo
from .facet_key_attribute import FacetKeyAttribute
from .facet_statistics import FacetStatistics
from .facet_term import FacetTerm
from .fax_document import FaxDocument
from .fax_document_entity_listing import FaxDocumentEntityListing
from .fax_send_request import FaxSendRequest
from .fax_send_response import FaxSendResponse
from .fax_summary import FaxSummary
from .geolocation import Geolocation
from .geolocation_settings import GeolocationSettings
from .greeting import Greeting
from .greeting_audio_file import GreetingAudioFile
from .greeting_media_info import GreetingMediaInfo
from .greeting_owner import GreetingOwner
from .group import Group
from .group_entity_listing import GroupEntityListing
from .group_members_update import GroupMembersUpdate
from .group_search_criteria import GroupSearchCriteria
from .group_search_request import GroupSearchRequest
from .groups_search_response import GroupsSearchResponse
from .import_status import ImportStatus
from .inbound_domain import InboundDomain
from .inbound_domain_entity_listing import InboundDomainEntityListing
from .inbound_route import InboundRoute
from .inbound_route_entity_listing import InboundRouteEntityListing
from .initiate_screen_recording import InitiateScreenRecording
from .interaction_stats_alert import InteractionStatsAlert
from .interaction_stats_alert_container import InteractionStatsAlertContainer
from .interaction_stats_rule import InteractionStatsRule
from .interaction_stats_rule_container import InteractionStatsRuleContainer
from .json_node import JsonNode
from .json_node_search_response import JsonNodeSearchResponse
from .key_rotation_schedule import KeyRotationSchedule
from .keyword import Keyword
from .keyword_set import KeywordSet
from .keyword_set_entity_listing import KeywordSetEntityListing
from .language import Language
from .language_entity_listing import LanguageEntityListing
from .library import Library
from .library_entity_listing import LibraryEntityListing
from .line import Line
from .line_base import LineBase
from .line_base_entity_listing import LineBaseEntityListing
from .line_entity_listing import LineEntityListing
from .line_status import LineStatus
from .location import Location
from .location_address import LocationAddress
from .location_emergency_number import LocationEmergencyNumber
from .location_search_criteria import LocationSearchCriteria
from .location_search_request import LocationSearchRequest
from .locations_search_response import LocationsSearchResponse
from .lock_info import LockInfo
from .logical_interface_entity_listing import LogicalInterfaceEntityListing
from .max_participants import MaxParticipants
from .media_participant_request import MediaParticipantRequest
from .media_policies import MediaPolicies
from .media_result import MediaResult
from .media_setting import MediaSetting
from .media_summary import MediaSummary
from .media_summary_detail import MediaSummaryDetail
from .member_entity import MemberEntity
from .metabase import Metabase
from .metered_evaluation_assignment import MeteredEvaluationAssignment
from .number import Number
from .number_plan import NumberPlan
from .numeric_range import NumericRange
from .o_auth_client import OAuthClient
from .o_auth_client_entity_listing import OAuthClientEntityListing
from .o_auth_provider import OAuthProvider
from .o_auth_provider_entity_listing import OAuthProviderEntityListing
from .observation_data_container import ObservationDataContainer
from .observation_query import ObservationQuery
from .observation_query_response import ObservationQueryResponse
from .okta import Okta
from .one_login import OneLogin
from .org_media_utilization import OrgMediaUtilization
from .organization import Organization
from .organization_presence import OrganizationPresence
from .organization_presence_entity_listing import OrganizationPresenceEntityListing
from .organization_product_entity_listing import OrganizationProductEntityListing
from .organization_role_entity_listing import OrganizationRoleEntityListing
from .orphan_recording import OrphanRecording
from .orphan_recording_listing import OrphanRecordingListing
from .out_of_office import OutOfOffice
from .outbound_route import OutboundRoute
from .outbound_route_entity_listing import OutboundRouteEntityListing
from .pin_configuration import PINConfiguration
from .paging_spec import PagingSpec
from .parameter import Parameter
from .parsed_certificate import ParsedCertificate
from .participant import Participant
from .participant_attributes import ParticipantAttributes
from .permission_collection_entity_listing import PermissionCollectionEntityListing
from .phone import Phone
from .phone_base import PhoneBase
from .phone_base_entity_listing import PhoneBaseEntityListing
from .phone_capabilities import PhoneCapabilities
from .phone_column import PhoneColumn
from .phone_entity_listing import PhoneEntityListing
from .phone_meta_base_entity_listing import PhoneMetaBaseEntityListing
from .phone_number_column import PhoneNumberColumn
from .phone_number_status import PhoneNumberStatus
from .phone_status import PhoneStatus
from .phones_reboot import PhonesReboot
from .physical_interface_entity_listing import PhysicalInterfaceEntityListing
from .policy import Policy
from .policy_actions import PolicyActions
from .policy_conditions import PolicyConditions
from .policy_entity_listing import PolicyEntityListing
from .policy_error_message import PolicyErrorMessage
from .policy_errors import PolicyErrors
from .prediction_results import PredictionResults
from .presence_query_response import PresenceQueryResponse
from .property_index_request import PropertyIndexRequest
from .provision_info import ProvisionInfo
from .pure_cloud import PureCloud
from .qualifier_mapping_observation_query_response import QualifierMappingObservationQueryResponse
from .quality_audit import QualityAudit
from .quality_audit_page import QualityAuditPage
from .query_facet_info import QueryFacetInfo
from .query_request import QueryRequest
from .query_result import QueryResult
from .query_results import QueryResults
from .question_group import QuestionGroup
from .question_group_score import QuestionGroupScore
from .question_score import QuestionScore
from .queue import Queue
from .queue_entity_listing import QueueEntityListing
from .queue_member import QueueMember
from .queue_utilization_diagnostic import QueueUtilizationDiagnostic
from .reaction import Reaction
from .recording import Recording
from .recording_email_message import RecordingEmailMessage
from .recording_settings import RecordingSettings
from .replace_request import ReplaceRequest
from .replace_response import ReplaceResponse
from .report_meta_data import ReportMetaData
from .report_meta_data_entity_listing import ReportMetaDataEntityListing
from .report_run_entry import ReportRunEntry
from .report_run_entry_entity_domain_listing import ReportRunEntryEntityDomainListing
from .report_schedule import ReportSchedule
from .report_schedule_entity_listing import ReportScheduleEntityListing
from .resource_condition_node import ResourceConditionNode
from .resource_condition_value import ResourceConditionValue
from .resource_permission_policy import ResourcePermissionPolicy
from .response import Response
from .response_entity_list import ResponseEntityList
from .response_entity_listing import ResponseEntityListing
from .response_filter import ResponseFilter
from .response_query_request import ResponseQueryRequest
from .response_query_results import ResponseQueryResults
from .response_set import ResponseSet
from .response_set_entity_listing import ResponseSetEntityListing
from .response_text import ResponseText
from .rest_error_detail import RestErrorDetail
from .retention_duration import RetentionDuration
from .ring import Ring
from .routing_data import RoutingData
from .routing_skill import RoutingSkill
from .routing_status import RoutingStatus
from .rule_set import RuleSet
from .rule_set_entity_listing import RuleSetEntityListing
from .run_now_response import RunNowResponse
from .salesforce import Salesforce
from .schedule_interval import ScheduleInterval
from .schema_category import SchemaCategory
from .schema_category_entity_listing import SchemaCategoryEntityListing
from .schema_reference_entity_listing import SchemaReferenceEntityListing
from .screen_recording_session import ScreenRecordingSession
from .screen_recording_session_listing import ScreenRecordingSessionListing
from .search_aggregation import SearchAggregation
from .search_criteria import SearchCriteria
from .search_request import SearchRequest
from .security_profile import SecurityProfile
from .security_profile_entity_listing import SecurityProfileEntityListing
from .segment import Segment
from .sequence_schedule import SequenceSchedule
from .server_date import ServerDate
from .service_context import ServiceContext
from .service_level import ServiceLevel
from .share import Share
from .share_entity_listing import ShareEntityListing
from .shared_entity import SharedEntity
from .site import Site
from .site_entity_listing import SiteEntityListing
from .skill_entity_listing import SkillEntityListing
from .skills_to_remove import SkillsToRemove
from .social_expression import SocialExpression
from .sort_item import SortItem
from .station import Station
from .station_entity_listing import StationEntityListing
from .statistical_response import StatisticalResponse
from .statistical_summary import StatisticalSummary
from .street_address import StreetAddress
from .subscriber_response import SubscriberResponse
from .suggest_search_criteria import SuggestSearchCriteria
from .suggest_search_request import SuggestSearchRequest
from .system_presence import SystemPresence
from .tag_query_request import TagQueryRequest
from .tag_value import TagValue
from .tag_value_entity_listing import TagValueEntityListing
from .term_attribute import TermAttribute
from .time_allowed import TimeAllowed
from .time_interval import TimeInterval
from .time_slot import TimeSlot
from .time_zone import TimeZone
from .time_zone_entity_listing import TimeZoneEntityListing
from .transfer_request import TransferRequest
from .trunk import Trunk
from .trunk_base import TrunkBase
from .trunk_base_assignment import TrunkBaseAssignment
from .trunk_entity_listing import TrunkEntityListing
from .trunk_metabase_entity_listing import TrunkMetabaseEntityListing
from .trunk_recording_enabled_count import TrunkRecordingEnabledCount
from .unread_metric import UnreadMetric
from .unread_status import UnreadStatus
from .uri_reference import UriReference
from .usage import Usage
from .usage_item import UsageItem
from .user import User
from .user_authorization import UserAuthorization
from .user_conversation_summary import UserConversationSummary
from .user_entity_listing import UserEntityListing
from .user_image import UserImage
from .user_me import UserMe
from .user_param import UserParam
from .user_presence import UserPresence
from .user_queue import UserQueue
from .user_queue_entity_listing import UserQueueEntityListing
from .user_recording import UserRecording
from .user_recording_entity_listing import UserRecordingEntityListing
from .user_routing_skill import UserRoutingSkill
from .user_search_criteria import UserSearchCriteria
from .user_search_request import UserSearchRequest
from .user_skill_entity_listing import UserSkillEntityListing
from .user_station import UserStation
from .user_stations import UserStations
from .users_entity_listing import UsersEntityListing
from .users_search_response import UsersSearchResponse
from .utilization import Utilization
from .validate_address_request import ValidateAddressRequest
from .validate_address_response import ValidateAddressResponse
from .video import Video
from .voicemail_mailbox_info import VoicemailMailboxInfo
from .voicemail_media_info import VoicemailMediaInfo
from .voicemail_message import VoicemailMessage
from .voicemail_message_entity_listing import VoicemailMessageEntityListing
from .voicemail_organization_policy import VoicemailOrganizationPolicy
from .voicemail_user_policy import VoicemailUserPolicy
from .workspace import Workspace
from .workspace_create import WorkspaceCreate
from .workspace_entity_listing import WorkspaceEntityListing
from .workspace_member import WorkspaceMember
from .workspace_member_entity_listing import WorkspaceMemberEntityListing
from .workspace_summary import WorkspaceSummary
from .wrap_up_code_mapping import WrapUpCodeMapping
from .wrapup import Wrapup
from .wrapup_code import WrapupCode
from .wrapup_code_entity_listing import WrapupCodeEntityListing



# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class Group(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Group - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'date_modified': 'datetime',
            'member_count': 'int',
            'state': 'str',
            'version': 'int',
            'type': 'str',
            'images': 'list[UserImage]',
            'addresses': 'list[Contact]',
            'rules_visible': 'bool',
            'visibility': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'date_modified': 'dateModified',
            'member_count': 'memberCount',
            'state': 'state',
            'version': 'version',
            'type': 'type',
            'images': 'images',
            'addresses': 'addresses',
            'rules_visible': 'rulesVisible',
            'visibility': 'visibility',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._description = None
        self._date_modified = None
        self._member_count = None
        self._state = None
        self._version = None
        self._type = None
        self._images = None
        self._addresses = None
        self._rules_visible = False
        self._visibility = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this Group.
        The globally unique identifier for the object.

        :return: The id of this Group.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Group.
        The globally unique identifier for the object.

        :param id: The id of this Group.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Group.


        :return: The name of this Group.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Group.


        :param name: The name of this Group.
        :type: str
        """
        
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this Group.


        :return: The description of this Group.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Group.


        :param description: The description of this Group.
        :type: str
        """
        
        self._description = description

    @property
    def date_modified(self):
        """
        Gets the date_modified of this Group.
        Last modified date/time. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_modified of this Group.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this Group.
        Last modified date/time. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_modified: The date_modified of this Group.
        :type: datetime
        """
        
        self._date_modified = date_modified

    @property
    def member_count(self):
        """
        Gets the member_count of this Group.
        Number of members.

        :return: The member_count of this Group.
        :rtype: int
        """
        return self._member_count

    @member_count.setter
    def member_count(self, member_count):
        """
        Sets the member_count of this Group.
        Number of members.

        :param member_count: The member_count of this Group.
        :type: int
        """
        
        self._member_count = member_count

    @property
    def state(self):
        """
        Gets the state of this Group.
        Active, inactive, or deleted state.

        :return: The state of this Group.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this Group.
        Active, inactive, or deleted state.

        :param state: The state of this Group.
        :type: str
        """
        allowed_values = ["active", "inactive", "deleted"]
        if state not in allowed_values:
            raise ValueError(
                "Invalid value for `state`, must be one of {0}"
                .format(allowed_values)
            )

        self._state = state

    @property
    def version(self):
        """
        Gets the version of this Group.
        Current version for this resource.

        :return: The version of this Group.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this Group.
        Current version for this resource.

        :param version: The version of this Group.
        :type: int
        """
        
        self._version = version

    @property
    def type(self):
        """
        Gets the type of this Group.
        Type of group.

        :return: The type of this Group.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this Group.
        Type of group.

        :param type: The type of this Group.
        :type: str
        """
        allowed_values = ["official", "social"]
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type`, must be one of {0}"
                .format(allowed_values)
            )

        self._type = type

    @property
    def images(self):
        """
        Gets the images of this Group.


        :return: The images of this Group.
        :rtype: list[UserImage]
        """
        return self._images

    @images.setter
    def images(self, images):
        """
        Sets the images of this Group.


        :param images: The images of this Group.
        :type: list[UserImage]
        """
        
        self._images = images

    @property
    def addresses(self):
        """
        Gets the addresses of this Group.


        :return: The addresses of this Group.
        :rtype: list[Contact]
        """
        return self._addresses

    @addresses.setter
    def addresses(self, addresses):
        """
        Sets the addresses of this Group.


        :param addresses: The addresses of this Group.
        :type: list[Contact]
        """
        
        self._addresses = addresses

    @property
    def rules_visible(self):
        """
        Gets the rules_visible of this Group.
        Are membership rules visible to the person requesting to view the group

        :return: The rules_visible of this Group.
        :rtype: bool
        """
        return self._rules_visible

    @rules_visible.setter
    def rules_visible(self, rules_visible):
        """
        Sets the rules_visible of this Group.
        Are membership rules visible to the person requesting to view the group

        :param rules_visible: The rules_visible of this Group.
        :type: bool
        """
        
        self._rules_visible = rules_visible

    @property
    def visibility(self):
        """
        Gets the visibility of this Group.
        Who can view this group

        :return: The visibility of this Group.
        :rtype: str
        """
        return self._visibility

    @visibility.setter
    def visibility(self, visibility):
        """
        Sets the visibility of this Group.
        Who can view this group

        :param visibility: The visibility of this Group.
        :type: str
        """
        allowed_values = ["public", "owners", "members"]
        if visibility not in allowed_values:
            raise ValueError(
                "Invalid value for `visibility`, must be one of {0}"
                .format(allowed_values)
            )

        self._visibility = visibility

    @property
    def self_uri(self):
        """
        Gets the self_uri of this Group.
        The URI for this object

        :return: The self_uri of this Group.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this Group.
        The URI for this object

        :param self_uri: The self_uri of this Group.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class Detail(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Detail - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'error_code': 'str',
            'field_name': 'str',
            'entity_id': 'str',
            'entity_name': 'str'
        }

        self.attribute_map = {
            'error_code': 'errorCode',
            'field_name': 'fieldName',
            'entity_id': 'entityId',
            'entity_name': 'entityName'
        }

        self._error_code = None
        self._field_name = None
        self._entity_id = None
        self._entity_name = None

    @property
    def error_code(self):
        """
        Gets the error_code of this Detail.


        :return: The error_code of this Detail.
        :rtype: str
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        """
        Sets the error_code of this Detail.


        :param error_code: The error_code of this Detail.
        :type: str
        """
        
        self._error_code = error_code

    @property
    def field_name(self):
        """
        Gets the field_name of this Detail.


        :return: The field_name of this Detail.
        :rtype: str
        """
        return self._field_name

    @field_name.setter
    def field_name(self, field_name):
        """
        Sets the field_name of this Detail.


        :param field_name: The field_name of this Detail.
        :type: str
        """
        
        self._field_name = field_name

    @property
    def entity_id(self):
        """
        Gets the entity_id of this Detail.


        :return: The entity_id of this Detail.
        :rtype: str
        """
        return self._entity_id

    @entity_id.setter
    def entity_id(self, entity_id):
        """
        Sets the entity_id of this Detail.


        :param entity_id: The entity_id of this Detail.
        :type: str
        """
        
        self._entity_id = entity_id

    @property
    def entity_name(self):
        """
        Gets the entity_name of this Detail.


        :return: The entity_name of this Detail.
        :rtype: str
        """
        return self._entity_name

    @entity_name.setter
    def entity_name(self, entity_name):
        """
        Sets the entity_name of this Detail.


        :param entity_name: The entity_name of this Detail.
        :type: str
        """
        
        self._entity_name = entity_name

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

